@@ -17,15 +17,15 @@ verbose. The ``@overload`` is on the ``cls`` argument:
 - in one signature, ``cls`` has type ``None`` and it's set to ``None``; in this
   case the type of the instantiated command is ``cloup.Command`` for ``@command``
   and ``cloup.Group`` for ``@group``
-- in the other signature, there's ``cls: ClickCommand`` without a default, where
-  ``ClickCommand`` is a type variable.
+- in the other signature, there's ``cls: C`` without a default, where ``C`` is
+  a type variable; in this case the type of the instantiated command is ``C``.
 
 When and if the MyPy issue is resolved, the overloads will be removed.
 """
 import inspect
 from typing import (
-    Any, Callable, Dict, Iterable, List, NamedTuple, Optional, Tuple, Type,
-    TypeVar, Union, cast, overload,
+    Any, Callable, Dict, Iterable, List, NamedTuple, Optional, Sequence, Tuple,
+    Type, TypeVar, Union, cast, overload, MutableMapping, Mapping,
 )
 
 import click
@@ -36,10 +36,12 @@ from ._option_groups import OptionGroupMixin
 from ._sections import Section, SectionMixin
 from ._util import click_version_ge_8_1, first_bool, reindent
 from .constraints import ConstraintMixin
+from .styling import DEFAULT_THEME
 from .typing import AnyCallable
 
-ClickCommand = TypeVar('ClickCommand', bound=click.Command)
-ClickGroup = TypeVar('ClickGroup', bound=click.Group)
+# Generic types of ``cls`` args of ``@command`` and ``@group``
+C = TypeVar('C', bound=click.Command)
+G = TypeVar('G', bound=click.Group)
 
 
 class Command(ConstraintMixin, OptionGroupMixin, click.Command):
@@ -141,7 +143,12 @@ class Group(SectionMixin, Command, click.Group):
     SHOW_SUBCOMMAND_ALIASES: bool = False
 
     def __init__(
-        self, *args: Any, show_subcommand_aliases: Optional[bool] = None, **kwargs: Any
+        self, *args: Any,
+        show_subcommand_aliases: Optional[bool] = None,
+        commands: Optional[
+            Union[MutableMapping[str, click.Command], Sequence[click.Command]]
+        ] = None,
+        **kwargs: Any
     ):
         super().__init__(*args, **kwargs)
         self.show_subcommand_aliases = show_subcommand_aliases
@@ -150,6 +157,19 @@ class Group(SectionMixin, Command, click.Group):
         self.alias2name: Dict[str, str] = {}
         """Dictionary mapping each alias to a command name."""
 
+        if commands:
+            self.add_multiple_commands(commands)
+
+    def add_multiple_commands(
+        self, commands: Union[Mapping[str, click.Command], Sequence[click.Command]]
+    ) -> None:
+        if isinstance(commands, Mapping):
+            for name, cmd in commands.items():
+                self.add_command(cmd, name=name)
+        else:
+            for cmd in commands:
+                self.add_command(cmd)
+
     def add_command(
         self, cmd: click.Command,
         name: Optional[str] = None,
@@ -163,7 +183,7 @@ class Group(SectionMixin, Command, click.Group):
             self.alias2name[alias] = name
 
     def resolve_command_name(self, ctx: click.Context, name: str) -> Optional[str]:
-        """Maps a string supposed to be a command name or an alias to a normalized
+        """Map a string supposed to be a command name or an alias to a normalized
         command name. If no match is found, it returns ``None``."""
         if ctx.token_normalize_func:
             name = ctx.token_normalize_func(name)
@@ -227,10 +247,26 @@ class Group(SectionMixin, Command, click.Group):
     ) -> str:
         aliases = getattr(cmd, 'aliases', None)
         if aliases and self.must_show_subcommand_aliases(ctx):
-            alias_list = ', '.join(aliases)
-            return f"{name} ({alias_list})"
+            assert isinstance(ctx, cloup.Context)
+            theme = cast(
+                cloup.HelpTheme, ctx.formatter_settings.get("theme", DEFAULT_THEME)
+            )
+            alias_list = self.format_subcommand_aliases(aliases, theme)
+            return f"{name} {alias_list}"
         return name
 
+    @staticmethod
+    def format_subcommand_aliases(aliases: Sequence[str], theme: cloup.HelpTheme) -> str:
+        secondary_style = theme.alias_secondary
+        if secondary_style is None or secondary_style == theme.alias:
+            return theme.alias(f"({', '.join(aliases)})")
+        else:
+            return (
+                secondary_style("(")
+                + secondary_style(", ").join(theme.alias(alias) for alias in aliases)
+                + secondary_style(")")
+            )
+
     # MyPy complains because "Signature of "group" incompatible with supertype".
     # The supertype signature is (*args, **kwargs), which is compatible with
     # this provided that you pass all arguments (expect "name") as keyword arg.
@@ -239,7 +275,7 @@ class Group(SectionMixin, Command, click.Group):
         self, name: Optional[str] = None,
         *,
         aliases: Optional[Iterable[str]] = None,
-        cls: None = None,  # Command is cloup.Command
+        cls: None = None,  # default to Group.command_class or cloup.Command
         section: Optional[Section] = None,
         context_settings: Optional[Dict[str, Any]] = None,
         formatter_settings: Optional[Dict[str, Any]] = None,
@@ -254,7 +290,7 @@ class Group(SectionMixin, Command, click.Group):
         align_option_groups: Optional[bool] = None,
         show_constraints: Optional[bool] = None,
         params: Optional[List[click.Parameter]] = None,
-    ) -> Callable[[AnyCallable], Command]:
+    ) -> Callable[[AnyCallable], click.Command]:
         ...
 
     @overload
@@ -262,7 +298,7 @@ class Group(SectionMixin, Command, click.Group):
         self, name: Optional[str] = None,
         *,
         aliases: Optional[Iterable[str]] = None,
-        cls: Type[ClickCommand],
+        cls: Type[C],
         section: Optional[Section] = None,
         context_settings: Optional[Dict[str, Any]] = None,
         help: Optional[str] = None,
@@ -275,17 +311,17 @@ class Group(SectionMixin, Command, click.Group):
         deprecated: bool = False,
         params: Optional[List[click.Parameter]] = None,
         **kwargs: Any,
-    ) -> Callable[[AnyCallable], ClickCommand]:
+    ) -> Callable[[AnyCallable], C]:
         ...
 
     def command(
         self, name: Optional[str] = None, *,
         aliases: Optional[Iterable[str]] = None,
-        cls: Optional[Type[ClickCommand]] = None,
+        cls: Optional[Type[C]] = None,
         section: Optional[Section] = None,
         **kwargs: Any
-    ) -> Callable[[AnyCallable], Union[Command, ClickCommand]]:
-        """Returns a decorator that creates a new subcommand of this ``Group``
+    ) -> Callable[[AnyCallable], Union[click.Command, C]]:
+        """Return a decorator that creates a new subcommand of this ``Group``
         using the decorated function as callback.
 
         It takes the same arguments of :func:`command` plus:
@@ -296,9 +332,12 @@ class Group(SectionMixin, Command, click.Group):
         .. versionchanged:: 0.10.0
             all arguments but ``name`` are now keyword-only.
         """
-        make_command = command(name=name, cls=cls, aliases=aliases, **kwargs)
+        make_command = command(
+            name=name, cls=(self.command_class if cls is None else cls),
+            aliases=aliases, **kwargs
+        )
 
-        def decorator(f: AnyCallable) -> Union[Command, ClickCommand]:
+        def decorator(f: AnyCallable) -> click.Command:
             cmd = make_command(f)
             self.add_command(cmd, section=section)
             return cmd
@@ -330,14 +369,14 @@ class Group(SectionMixin, Command, click.Group):
         chain: bool = False,
         hidden: bool = False,
         deprecated: bool = False,
-    ) -> Callable[[AnyCallable], 'Group']:
+    ) -> Callable[[AnyCallable], click.Group]:
         ...
 
     @overload
     def group(  # Why overloading? Refer to module docstring.
         self, name: Optional[str] = None, *,
         aliases: Optional[Iterable[str]] = None,
-        cls: Type[ClickGroup],
+        cls: Optional[Type[G]] = None,
         section: Optional[Section] = None,
         invoke_without_command: bool = False,
         no_args_is_help: bool = False,
@@ -353,18 +392,18 @@ class Group(SectionMixin, Command, click.Group):
         deprecated: bool = False,
         params: Optional[List[click.Parameter]] = None,
         **kwargs: Any
-    ) -> Callable[[AnyCallable], ClickGroup]:
+    ) -> Callable[[AnyCallable], G]:
         ...
 
     def group(  # type: ignore
         self, name: Optional[None] = None,
         *,
-        cls: Optional[Type[ClickGroup]] = None,
+        cls: Optional[Type[G]] = None,
         aliases: Optional[Iterable[str]] = None,
         section: Optional[Section] = None,
         **kwargs: Any
-    ) -> Callable[[AnyCallable], Union["Group", ClickGroup]]:
-        """Returns a decorator that creates a new subcommand of this ``Group``
+    ) -> Callable[[AnyCallable], Union[click.Group, G]]:
+        """Return a decorator that creates a new subcommand of this ``Group``
         using the decorated function as callback.
 
         It takes the same argument of :func:`group` plus:
@@ -375,15 +414,26 @@ class Group(SectionMixin, Command, click.Group):
         .. versionchanged:: 0.10.0
             all arguments but ``name`` are now keyword-only.
         """
-        make_group = group(name=name, cls=cls, aliases=aliases, **kwargs)
+        make_group = group(
+            name=name, cls=cls or self._default_group_class(), aliases=aliases, **kwargs
+        )
 
-        def decorator(f: AnyCallable) -> Union["Group", ClickGroup]:
+        def decorator(f: AnyCallable) -> Union[click.Group, G]:
             cmd = make_group(f)
             self.add_command(cmd, section=section)
             return cmd
 
         return decorator
 
+    @classmethod
+    def _default_group_class(cls) -> Optional[Type[click.Group]]:
+        if cls.group_class is None:
+            return None
+        if cls.group_class is type:
+            return cls
+        else:
+            return cast(Type[click.Group], cls.group_class)
+
 
 # Why overloading? Refer to module docstring.
 @overload  # In this overload: "cls: None = None"
@@ -414,7 +464,7 @@ def command(  # In this overload: "cls: ClickCommand"
     name: Optional[str] = None,
     *,
     aliases: Optional[Iterable[str]] = None,
-    cls: Type[ClickCommand],
+    cls: Type[C],
     context_settings: Optional[Dict[str, Any]] = None,
     help: Optional[str] = None,
     short_help: Optional[str] = None,
@@ -426,7 +476,7 @@ def command(  # In this overload: "cls: ClickCommand"
     deprecated: bool = False,
     params: Optional[List[click.Parameter]] = None,
     **kwargs: Any
-) -> Callable[[AnyCallable], ClickCommand]:
+) -> Callable[[AnyCallable], C]:
     ...
 
 
@@ -434,11 +484,11 @@ def command(  # In this overload: "cls: ClickCommand"
 def command(
     name: Optional[str] = None, *,
     aliases: Optional[Iterable[str]] = None,
-    cls: Optional[Type[ClickCommand]] = None,
+    cls: Optional[Type[C]] = None,
     **kwargs: Any
-) -> Callable[[AnyCallable], Union[Command, ClickCommand]]:
+) -> Callable[[AnyCallable], Union[Command, C]]:
     """
-    Returns a decorator that creates a new command using the decorated function
+    Return a decorator that creates a new command using the decorated function
     as callback.
 
     The only differences with respect to ``click.command`` are:
@@ -521,7 +571,7 @@ def command(
             f"While parenthesis are optional in Click >= 8.1, they are required in Cloup."
         )
 
-    def decorator(f: AnyCallable) -> ClickCommand:
+    def decorator(f: AnyCallable) -> C:
         if hasattr(f, '__cloup_constraints__'):
             if cls and not issubclass(cls, ConstraintMixin):
                 raise TypeError(
@@ -531,9 +581,9 @@ def command(
             del f.__cloup_constraints__
             kwargs['constraints'] = constraints
 
-        cmd_cls = cls if cls is not None else Command
+        cmd_cls = cast(Type[Command], cls if cls is not None else Command)
         try:
-            cmd = cast(ClickCommand, click.command(name, cls=cmd_cls, **kwargs)(f))
+            cmd = cast(C, click.command(name, cls=cmd_cls, **kwargs)(f))
             if aliases:
                 cmd.aliases = list(aliases)  # type: ignore
             return cmd
@@ -573,7 +623,7 @@ def group(
 def group(
     name: Optional[str] = None,
     *,
-    cls: Type[ClickGroup],
+    cls: Type[G],
     aliases: Optional[Iterable[str]] = None,
     invoke_without_command: bool = False,
     no_args_is_help: bool = False,
@@ -589,15 +639,15 @@ def group(
     deprecated: bool = False,
     params: Optional[List[click.Parameter]] = None,
     **kwargs: Any
-) -> Callable[[AnyCallable], ClickGroup]:
+) -> Callable[[AnyCallable], G]:
     ...
 
 
 def group(
-    name: Optional[str] = None, *, cls: Optional[Type[ClickGroup]] = None, **kwargs: Any
+    name: Optional[str] = None, *, cls: Optional[Type[G]] = None, **kwargs: Any
 ) -> Callable[[AnyCallable], click.Group]:
     """
-    Returns a decorator that instantiates a ``Group`` (or a subclass of it)
+    Return a decorator that instantiates a ``Group`` (or a subclass of it)
     using the decorated function as callback.
 
     .. versionchanged:: 0.10.0
@@ -698,7 +748,7 @@ _ARGS_INFO = {
 def _process_unexpected_kwarg_error(
     error: TypeError, args_info: Dict[str, _ArgInfo], cls: Type[Command]
 ) -> TypeError:
-    """Checks if the developer tried to pass a Cloup-specific argument to a ``cls``
+    """Check if the developer tried to pass a Cloup-specific argument to a ``cls``
     that doesn't support it and if that's the case, augments the error message
     to provide useful more info about the error."""
     import re
