@@ -6,13 +6,13 @@ if TYPE_CHECKING:
     import cloup
 
 FORMATTER_TYPE_ERROR = """
-since cloup v0.8.0, this class relies on cloup.HelpFormatter to align help
-sections. So, you need to make sure your command class uses cloup.HelpFormatter
+since Cloup v0.8, this class relies on `cloup.HelpFormatter` to align help
+sections. So, you need to make sure your command class uses `cloup.HelpFormatter`
 as formatter class.
 
-If you have your own custom HelpFormatter, know that cloup.HelpFormatter is
+If you have your own custom `HelpFormatter`, know that `cloup.HelpFormatter` is
 more easily customizable then Click's one, so consider extending it instead
-of extending click.HelpFormatter.
+of extending `click.HelpFormatter`.
 """
 
 
