@@ -2,18 +2,20 @@
 Parameter types and "shortcuts" for creating commonly used types.
 """
 import pathlib
+from typing import Type, Any
 
 import click
 
 
 def path(
     *,
-    path_type: type = pathlib.Path,
+    path_type: Type[Any] = pathlib.Path,
     exists: bool = False,
     file_okay: bool = True,
     dir_okay: bool = True,
-    writable: bool = False,
     readable: bool = True,
+    writable: bool = False,
+    executable: bool = False,
     resolve_path: bool = False,
     allow_dash: bool = False,
 ) -> click.Path:
@@ -23,10 +25,11 @@ def path(
 
 def dir_path(
     *,
-    path_type: type = pathlib.Path,
+    path_type: Type[Any] = pathlib.Path,
     exists: bool = False,
-    writable: bool = False,
     readable: bool = True,
+    writable: bool = False,
+    executable: bool = False,
     resolve_path: bool = False,
     allow_dash: bool = False,
 ) -> click.Path:
@@ -37,10 +40,11 @@ def dir_path(
 
 def file_path(
     *,
-    path_type: type = pathlib.Path,
+    path_type: Type[Any] = pathlib.Path,
     exists: bool = False,
-    writable: bool = False,
     readable: bool = True,
+    writable: bool = False,
+    executable: bool = False,
     resolve_path: bool = False,
     allow_dash: bool = False,
 ) -> click.Path:
